##  Unsubscribing from Fact Sheets
To unsubscribe from a fact sheet, do the following:
  1. In the fact sheet, navigate to the Subscriptions tab.
  2. Click the edit icon (depicted by a pencil) next to the subscriber you want to unsubscribe. This action opens an overlay.
  3. Click Delete Subscription to finish unsubscribing.
